@@ -1,5 +1,25 @@
 package Catalyst::ActionContainer;
 
+use strict;
+use base qw/Class::Accessor::Fast/;
+
+__PACKAGE__->mk_accessors(qw/part actions/);
+
+use overload (
+
+    # Stringify to path part for tree search
+    q{""} => sub { shift->{part} },
+
+);
+
+sub new {
+    my ( $class, $fields ) = @_;
+
+    $fields = { part => $fields, actions => {} } unless ref $fields;
+
+    $class->SUPER::new($fields);
+}
+
 =head1 NAME
 
 Catalyst::ActionContainer - Catalyst Action Container
@@ -13,45 +33,6 @@ See L<Catalyst>.
 This is a container for actions. The dispatcher sets up a tree of these
 to represent the various dispatch points in your application.
 
-=cut
-
-use Moose;
-with 'MooseX::Emulate::Class::Accessor::Fast';
-
-has part => (is => 'rw', required => 1);
-has actions => (is => 'rw', required => 1, lazy => 1, default => sub { {} });
-
-around BUILDARGS => sub {
-    my ($next, $self, @args) = @_;
-    unshift @args, 'part' if scalar @args == 1 && !ref $args[0];
-    return $self->$next(@args);
-};
-
-no Moose;
-
-use overload (
-    # Stringify to path part for tree search
-    q{""} => sub { shift->part },
-);
-
-sub get_action {
-    my ( $self, $name ) = @_;
-    return $self->actions->{$name} if defined $self->actions->{$name};
-    return;
-}
-
-sub add_action {
-    my ( $self, $action, $name ) = @_;
-    $name ||= $action->name;
-    $self->actions->{$name} = $action;
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
-
-__END__
-
 =head1 METHODS
 
 =head2 new(\%data | $part)
@@ -64,10 +45,26 @@ hashref to be populated via add_action later
 
 Returns an action from this container based on the action name, or undef
 
+=cut
+
+sub get_action {
+    my ( $self, $name ) = @_;
+    return $self->actions->{$name} if defined $self->actions->{$name};
+    return;
+}
+
 =head2 add_action($action, [ $name ])
 
 Adds an action, optionally providing a name to override $action->name
 
+=cut
+
+sub add_action {
+    my ( $self, $action, $name ) = @_;
+    $name ||= $action->name;
+    $self->actions->{$name} = $action;
+}
+
 =head2 actions
 
 Accessor to the actions hashref, containing all actions in this container.
@@ -77,17 +74,13 @@ Accessor to the actions hashref, containing all actions in this container.
 Accessor to the path part this container resolves to. Also what the container
 stringifies to.
 
-=head2 meta
+=head1 AUTHOR
 
-Provided by Moose
-
-=head1 AUTHORS
-
-Catalyst Contributors, see Catalyst.pm
+Matt S. Trout
 
 =head1 COPYRIGHT
 
-This library is free software. You can redistribute it and/or modify it under
+This program is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
