@@ -1,3 +1,5 @@
+#!perl
+
 # Run all tests against FastCGI mode under Apache
 #
 # Note, to get this to run properly, you may need to give it the path to your
@@ -29,13 +31,7 @@ File::Copy::Recursive::dircopy( 't/lib', 't/tmp/TestApp/lib' );
 # remove TestApp's tests so Apache::Test doesn't try to run them
 rmtree 't/tmp/TestApp/t';
 
-$ENV{CATALYST_SERVER} = 'http://localhost:8529';
-
-if ( !-e 't/optional_apache-fastcgi.pl' ) {
-    die "ERROR: Please run test from the Catalyst-Runtime directory\n";
-}
-
-push @ARGV, glob( 't/aggregate/live_*' );
+$ENV{CATALYST_SERVER} = 'http://localhost:8529/fastcgi';
 
 Apache::TestRun->new->run(@ARGV);
 
